pub struct FuelCallResponse<D> {
pub value: D,
pub receipts: Vec<Receipt>,
pub gas_used: u64,
pub log_decoder: LogDecoder,
}Expand description
FuelCallResponse is a struct that is returned by a call to the contract or script. Its value
field holds the decoded typed value returned by the contract’s method. The other field holds all
the receipts returned by the call.
The name is FuelCallResponse instead of CallResponse because it would be ambiguous with the
CALL opcode.
Fields
value: Dreceipts: Vec<Receipt>gas_used: u64log_decoder: LogDecoderImplementations
Sourceimpl<D> FuelCallResponse<D>
impl<D> FuelCallResponse<D>
pub fn new(value: D, receipts: Vec<Receipt>, log_decoder: LogDecoder) -> Self
pub fn get_logs(&self) -> Result<Vec<String>, Error>
pub fn get_logs_with_type<T: Tokenizable + Parameterize>( &self, ) -> Result<Vec<T>, Error>