Module fuels_contract::script
source · [−]Structs
Script is a very thin layer on top of fuel-client with some extra functionalities needed and provided by the SDK.
Script is a very thin layer on top of fuel-client with some extra functionalities needed and provided by the SDK.