pub struct Script {
    pub tx: Transaction,
}
Script is a very thin layer on top of fuel-client with some extra functionalities needed and provided by the SDK.

Fields

tx: Transaction

Implementations

Compiles a Sway script