Struct fuels_contract::script::Script
source · [−]pub struct Script {
pub tx: Transaction,
}Expand description
Script is a very thin layer on top of fuel-client with some extra functionalities needed and provided by the SDK.
Fields
tx: TransactionImplementations
sourceimpl Script
impl Script
pub fn new(tx: Transaction) -> Self
pub async fn call(self, fuel_client: &FuelClient) -> Result<Vec<Receipt>, Error>
sourcepub fn compile_sway_script(project_path: &str) -> Result<CompiledScript, Error>
pub fn compile_sway_script(project_path: &str) -> Result<CompiledScript, Error>
Compiles a Sway script